@@ -48,6 +48,13 @@ python -c "from {file[:-3]} import {class_name};\\\n  {class_name}().{func_name}
     os.environ['TIME_STR'] = '0'
   return command, outdir
 
+def use_moxing():
+  tl_mox = True
+  try:
+    import moxing as mox
+  except:
+    tl_mox = False
+  return tl_mox
 
 def _build_parser(parser=None, append_local_rank=False):
   if not parser:
@@ -59,7 +66,7 @@ def _build_parser(parser=None, append_local_rank=False):
   parser.add_argument('--tl_resume', action='store_true', default=False)
   parser.add_argument('--tl_resumedir', type=str, default='results/temp')
   parser.add_argument('--tl_debug', action='store_true', default=False)
-  argparser_utils.add_argument_bool(parser, 'tl_mox', default=True)
+  argparser_utils.add_argument_bool(parser, 'tl_mox', default=use_moxing())
 
   parser.add_argument('--tl_time_str', type=str, default='')
   if append_local_rank:
