@@ -62,7 +62,7 @@ def modelarts_sync_results_dir(cfg, join=False, is_main_process=True):
     logger.info(f'\n======End uploading results dir======')
   except:
     import traceback
-    logger.info(traceback.format_exc())
+    logger.info(traceback.format_exc() + " *** Feel free to ignore this error *** ")
     logger.info(f'\n======End uploading results dir======')
   return
 
