@@ -129,7 +129,7 @@ class PlotResults(object):
                     label2datas[label] = data
             axes[idx].legend(prop={'size': legend_size})
             axes[idx].set(**default_dict['properties'])
-            axes[idx].grid(b=True, which='major', color='#666666', linestyle='--', alpha=0.2)
+            axes[idx].grid(visible=True, which='major', color='#666666', linestyle='--', alpha=0.2)
                     
             label2datas_list[dict_name] = label2datas
         fig.show()
@@ -248,6 +248,63 @@ class TestingPlot(unittest.TestCase):
         print(f"Save data to {saved_data}")
         pass
 
+    def test__plot_text_bucket(self):
+      """
+      python -c "from exp.tests.test_styleganv2 import Testing_stylegan2_style_position;\
+        Testing_stylegan2_style_position().test_plot_FID_cifar10_style_position()"
+      """
+      if 'CUDA_VISIBLE_DEVICES' not in os.environ:
+        os.environ['CUDA_VISIBLE_DEVICES'] = '0'
+      if 'TIME_STR' not in os.environ:
+        os.environ['TIME_STR'] = '0'
+      from tl2.launch.launch_utils import \
+        (get_command_and_outdir, setup_outdir_and_yaml, get_append_cmd_str, start_cmd_run)
+
+      command, outdir = get_command_and_outdir(self, func_name=sys._getframe().f_code.co_name, file=__file__)
+      argv_str = f"""
+                    --tl_config_file none
+                    --tl_command none
+                    --tl_outdir {outdir}
+                    """
+      args = setup_outdir_and_yaml(argv_str)
+      outdir = args.tl_outdir
+
+      from tl2.proj.matplot.plot_results import PlotResults
+      import collections
+      import pickle
+
+      outfigure = os.path.join(outdir, 'FID.jpg')
+      default_dicts = collections.OrderedDict()
+      show_max = []
+
+      bucket_root = "/home/ma-user/work/ZhouPeng/bucket_3690/"
+
+      FID_FFHQ_r128 = collections.defaultdict(dict)
+      title = 'FID_FFHQ_r128'
+      log_file = 'textdir/eval.ma0.FID.log'
+      dd = eval(title)
+      dd[f'{bucket_root}/results/stylegan3-exp/encoder_inr_train_v2/train_ffhq_r256_softplus-20211222_120944_857'] = \
+        {'20211222_120944_857-3dmm_210': f"{log_file}", }
+
+      dd['properties'] = {'title': title,
+                          # 'xlim': [0, 3000000],
+                          # 'ylim': [0, 100]
+                          }
+      default_dicts[title] = dd
+      show_max.append(False)
+
+      plotobs = PlotResults()
+      label2datas_list = plotobs.plot_defaultdicts(
+        outfigure=outfigure, default_dicts=default_dicts, show_max=show_max, figsize_wh=(16, 7.2))
+      print(f'Save to {outfigure}.')
+
+      saved_data = '__'.join(outdir.split('/')[-2:])
+      saved_data = f"{outdir}/{saved_data}.pkl"
+      with open(saved_data, 'wb') as f:
+        pickle.dump(label2datas_list, f)
+      print(f"Save data to {saved_data}")
+      pass
+
     def test_plot_results_pkl(self, debug=True):
       """
       Usage:
