@@ -20,7 +20,10 @@ def pil_resize(img_pil, size=()):
   :param size: (w, h)
   :return:
   """
-  img_pil = img_pil.resize(size, Image.Resampling.LANCZOS)
+  try:
+    img_pil = img_pil.resize(size, Image.Resampling.LANCZOS)
+  except AttributeError:
+    img_pil = img_pil.resize(size, Image.LANCZOS)
   return img_pil
 
 
@@ -161,7 +164,10 @@ def merge_image_pil(image_list, nrow: int = 8, saved_file=None, pad=0, pad_color
 
   if dst_size is not None:
     out_w, out_h = get_size(w=merged_image.size[0], h=merged_image.size[1], dst_size=dst_size, for_min_edge=False)
-    merged_image = merged_image.resize((out_w, out_h), Image.LANCZOS)
+    try:
+      merged_image = merged_image.resize((out_w, out_h), Image.Resampling.LANCZOS)
+    except AttributeError:
+      merged_image = merged_image.resize((out_w, out_h), Image.LANCZOS)
 
   if saved_file is not None:
     merged_image.save(saved_file)
