@@ -308,6 +308,7 @@ class Renderer_v1(object):
                color=[1.0, 1.0, 0.9],
                rgba_mode=False,
                mesh_filename=None,
+               vertex_colors=None,
                ):
     """
     sx, tx, ty = cam
@@ -334,18 +335,26 @@ class Renderer_v1(object):
     assert img.shape[:2] == (self.height, self.width)
     
     # add mesh
-    mesh = trimesh.Trimesh(vertices=verts, faces=faces, process=False)
+    mesh = trimesh.Trimesh(vertices=verts, faces=faces, process=False,
+                           vertex_colors=vertex_colors)
+      
     if mesh_filename is not None:
       mesh.export(mesh_filename)
-    if color_type != None:
-      color = self.colors_dict[color_type]
-    material = pyrender.MetallicRoughnessMaterial(
-      metallicFactor=0.2,
-      roughnessFactor=0.6,
-      alphaMode='OPAQUE',
-      baseColorFactor=(color[0], color[1], color[2], 1.0)
-    )
-    mesh = pyrender.Mesh.from_trimesh(mesh, material=material)
+    
+    if vertex_colors is None:
+      if color_type != None:
+        color = self.colors_dict[color_type]
+      material = pyrender.MetallicRoughnessMaterial(
+        metallicFactor=0.2,
+        roughnessFactor=0.6,
+        alphaMode='OPAQUE',
+        baseColorFactor=(color[0], color[1], color[2], 1.0)
+      )
+      mesh = pyrender.Mesh.from_trimesh(mesh, material=material)
+    else:
+      mesh.vertex_colors = vertex_colors
+      mesh = pyrender.Mesh.from_trimesh(mesh, smooth=False, wireframe=False)
+    
     mesh_node = self.scene.add(mesh, 'mesh')
     
     # add camera
