@@ -23,6 +23,105 @@ import hashlib
 import tempfile
 import pickle
 import subprocess
+import unittest
+import tyro
+
+
+def create_outdir(outdir):
+  TIME_STR = bool(int(os.getenv('TIME_STR', 0)))
+
+  time_str = datetime.now().strftime("%Y%m%d_%H%M%S_%f")[:-3]
+  outdir = outdir if not TIME_STR else f"{outdir}-{time_str}"
+
+  shutil.rmtree(outdir, ignore_errors=True)
+  os.makedirs(outdir)
+  return outdir
+  
+def get_func_name_and_outdir(
+      instance: unittest.TestCase,
+      func_name: str = sys._getframe().f_code.co_name,
+      file: str = __file__):
+  """
+  tl2_utils.get_func_name_and_outdir(self, file=__file__)
+
+  :param instance:
+  :param file:
+  :return:
+  - func_name: [test_]func_name
+  - outdir: Create outdir [append time string]
+  """
+
+  # class name
+  class_name = instance.__class__.__name__
+  assert instance.__class__.__name__.startswith('Testing_')
+  subdir = class_name[8:]
+
+  # func name
+  # func_name = instance._testMethodName
+  # func_name = sys._getframe().f_code.co_name
+  assert func_name.startswith('test_'), func_name
+  func_name = func_name[5:]
+
+  outdir = f'results/{subdir}/{func_name}'
+  create_outdir(outdir)
+
+  # print start command string
+  rel_file = os.path.relpath(os.path.realpath(file), os.path.realpath(os.path.curdir))
+  module_path = rel_file[:-3].replace('/', '.')
+  run_str = f"""
+*************************************************************
+python -c "from {module_path} import {class_name};\\\n  {class_name}().test_{func_name}()"\n
+*************************************************************
+             """
+  print(run_str.strip(' '))
+
+  return func_name, outdir
+
+def _fix_cmd_list(cmd: list):
+  cmd_fixed = []
+  cmd_queue = collections.deque(cmd)
+
+  temp_item = []
+  while cmd_queue:
+    item = cmd_queue.popleft()
+
+    if item.startswith('"') and item.endswith('"'):
+      cmd_fixed.append(item[1:-1])
+    elif item.startswith('"'):
+      temp_item.append(item[1:])
+    elif len(temp_item) > 0:
+      if item.endswith('"'):
+        temp_item.append(item[:-1])
+        cmd_fixed.append(' '.join(temp_item))
+        temp_item.clear()
+      else:
+        temp_item.append(item)
+    else:
+      cmd_fixed.append(item)
+  return cmd_fixed
+
+def system_run(cmd_str):
+  cmd = cmd_str.split()
+
+  cmd = _fix_cmd_list(cmd)
+
+  print('\nrun_str:\n' + ' \\\n  '.join(cmd))
+  current_env = os.environ.copy()
+
+  if cmd[0] == 'python':
+    cmd[0] = sys.executable
+    process = subprocess.Popen(cmd, env=current_env)
+
+  elif cmd[0] == 'bash':
+    process = subprocess.Popen(['/bin/bash', '-o', 'xtrace', '-c', ' '.join(cmd[1:])], env=current_env)
+
+  else:
+    process = subprocess.Popen(cmd, env=current_env)
+
+  process.wait()
+  if process.returncode != 0:
+    raise subprocess.CalledProcessError(returncode=process.returncode, cmd=cmd)
+  pass
 
 
 def int2bitstring(number):
@@ -85,8 +184,11 @@ def get_tempfile():
   temp_file.close()
 
   """
-  temp_file = tempfile.TemporaryFile('w+t')
-  return temp_file
+  # temp_file = tempfile.TemporaryFile('w+t')
+  # temp_file = tempfile.NamedTemporaryFile()
+  with tempfile.NamedTemporaryFile() as temp_file:
+    temp_file_path = temp_file.name
+  return temp_file_path
 
 
 def get_tempdir():
@@ -467,6 +569,14 @@ def unzip_file(zip_file, dst_dir):
   print(f'Unzip {zip_file} to {dst_dir}')
 
 
+def read_file_from_zip(zip_file,
+                       file_name):
+  with zipfile.ZipFile(zip_file, 'r') as fz:
+    data_bytes = fz.read(file_name)
+    data = pickle.loads(data_bytes)
+  return data
+
+
 def get_filelist_recursive(directory,
                            ext=('*.jpg', '*.png'),
                            sort=True,
@@ -668,3 +778,16 @@ def read_bytes(file_path):
   with open(file_path, 'rb') as fin:
     data_bytes = fin.read()
   return data_bytes
+
+
+def pycharm_remote_debug(host='localhost',
+                         port=8601):
+  if 'TL_DEBUG' not in os.environ:
+    return
+
+  # debug = bool(int(os.environ['TL_DEBUG']))
+  # if not debug:
+  #   return
+
+  import pydevd_pycharm
+  pydevd_pycharm.settrace(host=host, port=port, stdoutToServer=True, stderrToServer=True)
